@@ -3,6 +3,8 @@
 import os
 import re
 
+"""
+Made obsolete in July 2020
 def add_tab(fnm):
     newfile = []
     installtag = ' class="current"' if fnm.split('/')[-1] == 'installation.html' else ''
@@ -25,3 +27,19 @@ for pth, dnm, fnms in os.walk('./html/'):
     for fnm in fnms:
         if re.match('.*\.html$',fnm):
             add_tab(os.path.join(pth,fnm))
+"""
+
+menudata_js = """
+var menudata={children:[
+{text:"Main Page",url:"index.html"},
+{text:"Installation",url:"installation.html"},
+{text:"Usage",url:"usage.html"},
+{text:"Tutorial",url:"tutorial.html"},
+{text:"Glossary",url:"glossary.html"},
+{text:"Roadmap",url:"todo.html"},
+{text:"Files",url:"files.html",children:[
+{text:"File List",url:"files.html"}]}]}
+"""
+
+with open(os.path.join('html', 'menudata.js'), 'w') as f:
+    f.write(menudata_js)
