@@ -29,9 +29,12 @@ from forcebalance.molecule import Molecule
 from collections import OrderedDict, defaultdict, namedtuple
 # Rudimentary NetCDF file usage
 from scipy.io.netcdf import netcdf_file
+import warnings
 try:
     # Some functions require the Python API to sander "pysander"
-    import sander
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore")
+        import sander
 except:
     pass
 
