@@ -52,9 +52,15 @@ engname          = args.engine.lower()     # Name of the engine
 
 if engname == "openmm":
     try:
-        from simtk.unit import *
-        from simtk.openmm import *
-        from simtk.openmm.app import *
+        try:
+            from openmm.unit import *
+            from openmm import *
+            from openmm.app import *
+        except ImportError:
+            from simtk.unit import *
+            from simtk.openmm import *
+            from simtk.openmm.app import *
+
     except:
         traceback.print_exc()
         raise Exception("Cannot import OpenMM modules")
