@@ -598,6 +598,22 @@ class Target(with_metaclass(abc.ABCMeta, forcebalance.BaseClass)):
     def submit_jobs(self, mvals, AGrad=False, AHess=False):
         return
 
+    def remove_custom_dir(self, dnm, use_iterdir=True):
+        """
+        Removes a custom folder under the target folder; can be used to clean up microiteration folders.
+        """
+        ## Directory of the current iteration; if not None, then the simulation runs under
+        ## temp/target_name/iteration_number
+        ## The 'customdir' is customizable and can go below anything
+        absgetdir = os.path.join(self.root,self.tempdir)
+        if use_iterdir and Counter() is not None:
+            ## Not expecting more than ten thousand iterations
+            iterdir = "iter_%04i" % Counter()
+            absgetdir = os.path.join(absgetdir,iterdir)
+        # Append the folder name to be removed
+        absgetdir = os.path.join(absgetdir,dnm)
+        shutil.rmtree(absgetdir)
+
     def stage(self, mvals, AGrad=False, AHess=False, use_iterdir=True, customdir=None, firstIteration=False):
         """
 
@@ -820,7 +836,23 @@ class RemoteTarget(Target):
 
     def get(self,mvals,AGrad=False,AHess=False):
         with tarfile.open("target_result.tar.bz2", "r") as tar:
-            tar.extractall()
+            # Added by vulnerability checker to guard against directory traversal attack
+            def is_within_directory(directory, target):
+                abs_directory = os.path.abspath(directory)
+                abs_target = os.path.abspath(target)
+                prefix = os.path.commonprefix([abs_directory, abs_target])
+                return prefix == abs_directory
+            
+            def safe_extract(tar, path=".", members=None, *, numeric_owner=False):
+                for member in tar.getmembers():
+                    member_path = os.path.join(path, member.name)
+                    if not is_within_directory(path, member_path):
+                        raise Exception("Attempted Path Traversal in Tar File")
+                tar.extractall(path, members, numeric_owner=numeric_owner) 
+            
+            safe_extract(tar)
+        # Remove the target_result archive as it's not needed anymore.
+        os.unlink("target_result.tar.bz2")
         with open('indicate.log', 'r') as f:
             self.remote_indicate = f.read()
         return lp_load('objective.p')
